"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class PubSub {
    constructor({ eventStore }) {
        this.subscribe = (eventNames) => {
            return async (rootValue, args, { $$internal }) => {
                const { connection, operation, pubSub, registerSubscriptions, subscriptionManager, } = $$internal;
                const names = Array.isArray(eventNames) ? eventNames : [eventNames];
                // register subscriptions only if it set to do so
                // basically this means that client sent subscription operation over websocket
                // and we wan't to respond with GQL_SUBSCRIBED message
                if (registerSubscriptions) {
                    await subscriptionManager.subscribe(names, connection, 
                    // this is called only on subscription so operationId should be filled
                    operation);
                }
                return pubSub.asyncIterator(names);
            };
        };
        /**
         * Notice that this propagates event through storage
         * So you should not expect to fire in same process
         */
        this.publish = async (eventName, payload) => {
            await this.eventStore.publish({
                payload,
                event: eventName,
            });
        };
        this.eventStore = eventStore;
    }
}
exports.PubSub = PubSub;
exports.default = PubSub;
