"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_tools_1 = require("graphql-tools");
const PubSub_1 = __importDefault(require("../PubSub"));
const withFilter_1 = __importDefault(require("../withFilter"));
const typeDefs = /* GraphQL */ `
type Mutation {
    testMutation(text: String!): String!
    testPublish(authorId: ID!, text: String!): String!
  }

  type Query {
    delayed: Boolean!
    testQuery: String!
  }

  type Subscription {
    textFeed(authorId: ID!): String!
  }
`;
function createSchema({ pubSub = new PubSub_1.default({ eventStore: {} }), } = {}) {
    return graphql_tools_1.makeExecutableSchema({
        typeDefs,
        resolvers: {
            Mutation: {
                testMutation(rootValue, args) {
                    return args.text;
                },
                async testPublish(rootValue, args) {
                    await pubSub.publish('test', args);
                    return args.text;
                },
            },
            Query: {
                delayed: () => new Promise(r => setTimeout(() => r(true), 100)),
                testQuery() {
                    return 'test';
                },
            },
            Subscription: {
                textFeed: {
                    resolve: payload => payload.text,
                    subscribe: withFilter_1.default(pubSub.subscribe('test'), (payload, args) => payload.authorId === args.authorId),
                },
            },
        },
    });
}
exports.createSchema = createSchema;
exports.default = createSchema;
